#include <ctre.hpp>
using namespace ctre::test_literals;

void empty_symbol() { }

#if !CTRE_CNTTP_COMPILER_CHECK
#define CTRE_TEST(pattern) static_assert(pattern ## _ctre_test)
#else

template <ctll::fixed_string input> constexpr bool test() {
	constexpr auto _input = input;
	return ctll::parser<ctre::pcre, _input>::template correct_with<>;
}

#define CTRE_TEST(pattern) static_assert(test<pattern>())
#endif


CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");
CTRE_TEST("(tour|to|tournament)+\ntourna");

